def format_student_name(first, last):
    return f"{first.capitalize()} {last.capitalize()}"

def generate_student_email(student_id):
    return f"{student_id}@student.uni.edu"

def count_words(text):
    return len(text.split())


def calculate_gpa(grade_points):
    if not grade_points:
        return 0.0
    return sum(grade_points) / len(grade_points)

def has_passed(score, passing_mark=50):
    if score >= passing_mark:
        return "Pass"
    else:
        return "Fail"

def attendance_rate(classes_attended, total_classes):
    if total_classes == 0:
        return 0
    return (classes_attended / total_classes) * 100


from setuptools import setup, find_packages

setup(
    name="eman_student_tools_v1",  
    version="0.1",
    packages=find_packages(),
    description="A simple student utility library",
    author="Eman Mustafa",
    author_email="s2024332037@umt.edu.pk",
    install_requires=[], 
)